summaryrefslogtreecommitdiffstats
path: root/chromium/content/browser/media/android/media_resource_getter_impl.h
diff options
context:
space:
mode:
Diffstat (limited to 'chromium/content/browser/media/android/media_resource_getter_impl.h')
-rw-r--r--chromium/content/browser/media/android/media_resource_getter_impl.h19
1 files changed, 10 insertions, 9 deletions
diff --git a/chromium/content/browser/media/android/media_resource_getter_impl.h b/chromium/content/browser/media/android/media_resource_getter_impl.h
index 2b6e42ea313..c1ed4b97b36 100644
--- a/chromium/content/browser/media/android/media_resource_getter_impl.h
+++ b/chromium/content/browser/media/android/media_resource_getter_impl.h
@@ -32,11 +32,11 @@ class ResourceContext;
class MediaResourceGetterImpl : public media::MediaResourceGetter {
public:
// Construct a MediaResourceGetterImpl object. |browser_context| and
// |renderer_id| are passed to retrieve the CookieStore.
// |file_system_context| are used to get the platform path.
MediaResourceGetterImpl(BrowserContext* browser_context,
fileapi::FileSystemContext* file_system_context,
- int renderer_id, int routing_id);
+ int render_process_id, int render_frame_id);
virtual ~MediaResourceGetterImpl();
// media::MediaResourceGetter implementation.
@@ -44,11 +44,12 @@ class MediaResourceGetterImpl : public media::MediaResourceGetter {
virtual void GetCookies(const GURL& url,
const GURL& first_party_for_cookies,
const GetCookieCB& callback) OVERRIDE;
- virtual void GetPlatformPathFromFileSystemURL(
+ virtual void GetPlatformPathFromURL(
const GURL& url,
const GetPlatformPathCB& callback) OVERRIDE;
virtual void ExtractMediaMetadata(
const std::string& url, const std::string& cookies,
+ const std::string& user_agent,
const ExtractMediaMetadataCB& callback) OVERRIDE;
static bool RegisterMediaResourceGetter(JNIEnv* env);
@@ -68,14 +69,14 @@ class MediaResourceGetterImpl : public media::MediaResourceGetter {
// FileSystemContext to be used on FILE thread.
fileapi::FileSystemContext* file_system_context_;
- // Used to post tasks.
- base::WeakPtrFactory<MediaResourceGetterImpl> weak_this_;
-
// Render process id, used to check whether the process can access cookies.
- int renderer_id_;
+ int render_process_id_;
+
+ // Render frame id, used to check tab specific cookie policy.
+ int render_frame_id_;
- // Routing id for the render view, used to check tab specific cookie policy.
- int routing_id_;
+ // NOTE: Weak pointers must be invalidated before all other member variables.
+ base::WeakPtrFactory<MediaResourceGetterImpl> weak_factory_;
DISALLOW_COPY_AND_ASSIGN(MediaResourceGetterImpl);
};
@@ -32,11 +32,11 @@ class ResourceContext;
public:
// Construct a MediaResourceGetterImpl object. |browser_context| and
- // |renderer_id| are passed to retrieve the CookieStore.
+ // |render_process_id| are passed to retrieve the CookieStore.
// |file_system_context| are used to get the platform path.
MediaResourceGetterImpl(BrowserContext* browser_context,